Enum IStablecoinDEXErrors
pub enum IStablecoinDEXErrors {
Show 16 variants
Unauthorized(Unauthorized),
PairDoesNotExist(PairDoesNotExist),
PairAlreadyExists(PairAlreadyExists),
OrderDoesNotExist(OrderDoesNotExist),
IdenticalTokens(IdenticalTokens),
InvalidToken(InvalidToken),
TickOutOfBounds(TickOutOfBounds),
InvalidTick(InvalidTick),
InvalidFlipTick(InvalidFlipTick),
InsufficientBalance(InsufficientBalance),
InsufficientLiquidity(InsufficientLiquidity),
InsufficientOutput(InsufficientOutput),
MaxInputExceeded(MaxInputExceeded),
BelowMinimumOrderSize(BelowMinimumOrderSize),
InvalidBaseToken(InvalidBaseToken),
OrderNotStale(OrderNotStale),
}Expand description
Container for all the IStablecoinDEX custom errors.
Variants
PairDoesNotExist(PairDoesNotExist)
PairAlreadyExists(PairAlreadyExists)
OrderDoesNotExist(OrderDoesNotExist)
IdenticalTokens(IdenticalTokens)
InvalidToken(InvalidToken)
TickOutOfBounds(TickOutOfBounds)
InvalidTick(InvalidTick)
InvalidFlipTick(InvalidFlipTick)
InsufficientBalance(InsufficientBalance)
InsufficientLiquidity(InsufficientLiquidity)
InsufficientOutput(InsufficientOutput)
MaxInputExceeded(MaxInputExceeded)
BelowMinimumOrderSize(BelowMinimumOrderSize)
InvalidBaseToken(InvalidBaseToken)
OrderNotStale(OrderNotStale)
Implementations
impl IStablecoinDEXErrors
impl IStablecoinDEXErrors
pub const SELECTORS: &'static [[u8; 4]]
pub const SELECTORS: &'static [[u8; 4]]
All the selectors of this enum.
Note that the selectors might not be in the same order as the variants. No guarantees are made about the order of the selectors.
Prefer using SolInterface methods instead.
pub const VARIANT_NAMES: &'static [&'static str]
pub const VARIANT_NAMES: &'static [&'static str]
The names of the variants in the same order as SELECTORS.
pub const SIGNATURES: &'static [&'static str]
pub const SIGNATURES: &'static [&'static str]
The signatures in the same order as SELECTORS.
pub fn signature_by_selector(selector: [u8; 4]) -> Option<&'static str>
pub fn signature_by_selector(selector: [u8; 4]) -> Option<&'static str>
Returns the signature for the given selector, if known.
pub fn name_by_selector(selector: [u8; 4]) -> Option<&'static str>
pub fn name_by_selector(selector: [u8; 4]) -> Option<&'static str>
Returns the enum variant name for the given selector, if known.
impl IStablecoinDEXErrors
impl IStablecoinDEXErrors
Creates a Unauthorized error.
error Unauthorized()pub fn pair_does_not_exist() -> IStablecoinDEXErrors
pub fn pair_does_not_exist() -> IStablecoinDEXErrors
Creates a PairDoesNotExist error.
error PairDoesNotExist()pub fn pair_already_exists() -> IStablecoinDEXErrors
pub fn pair_already_exists() -> IStablecoinDEXErrors
Creates a PairAlreadyExists error.
error PairAlreadyExists()pub fn order_does_not_exist() -> IStablecoinDEXErrors
pub fn order_does_not_exist() -> IStablecoinDEXErrors
Creates a OrderDoesNotExist error.
error OrderDoesNotExist()pub fn identical_tokens() -> IStablecoinDEXErrors
pub fn identical_tokens() -> IStablecoinDEXErrors
Creates a IdenticalTokens error.
error IdenticalTokens()pub fn invalid_token() -> IStablecoinDEXErrors
pub fn invalid_token() -> IStablecoinDEXErrors
Creates a InvalidToken error.
error InvalidToken()pub fn tick_out_of_bounds(tick: i16) -> IStablecoinDEXErrors
pub fn tick_out_of_bounds(tick: i16) -> IStablecoinDEXErrors
Creates a TickOutOfBounds error.
error TickOutOfBounds(int16)pub fn invalid_tick() -> IStablecoinDEXErrors
pub fn invalid_tick() -> IStablecoinDEXErrors
Creates a InvalidTick error.
error InvalidTick()pub fn invalid_flip_tick() -> IStablecoinDEXErrors
pub fn invalid_flip_tick() -> IStablecoinDEXErrors
Creates a InvalidFlipTick error.
error InvalidFlipTick()pub fn insufficient_balance() -> IStablecoinDEXErrors
pub fn insufficient_balance() -> IStablecoinDEXErrors
Creates a InsufficientBalance error.
error InsufficientBalance()pub fn insufficient_liquidity() -> IStablecoinDEXErrors
pub fn insufficient_liquidity() -> IStablecoinDEXErrors
Creates a InsufficientLiquidity error.
error InsufficientLiquidity()pub fn insufficient_output() -> IStablecoinDEXErrors
pub fn insufficient_output() -> IStablecoinDEXErrors
Creates a InsufficientOutput error.
error InsufficientOutput()pub fn max_input_exceeded() -> IStablecoinDEXErrors
pub fn max_input_exceeded() -> IStablecoinDEXErrors
Creates a MaxInputExceeded error.
error MaxInputExceeded()pub fn below_minimum_order_size(amount: u128) -> IStablecoinDEXErrors
pub fn below_minimum_order_size(amount: u128) -> IStablecoinDEXErrors
Creates a BelowMinimumOrderSize error.
error BelowMinimumOrderSize(uint128)pub fn invalid_base_token() -> IStablecoinDEXErrors
pub fn invalid_base_token() -> IStablecoinDEXErrors
Creates a InvalidBaseToken error.
error InvalidBaseToken()pub fn order_not_stale() -> IStablecoinDEXErrors
pub fn order_not_stale() -> IStablecoinDEXErrors
Creates a OrderNotStale error.
error OrderNotStale()Trait Implementations
impl Clone for IStablecoinDEXErrors
impl Clone for IStablecoinDEXErrors
fn clone(&self) -> IStablecoinDEXErrors
fn clone(&self) -> IStablecoinDEXErrors
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreimpl Debug for IStablecoinDEXErrors
impl Debug for IStablecoinDEXErrors
impl<'de> Deserialize<'de> for IStablecoinDEXErrors
impl<'de> Deserialize<'de> for IStablecoinDEXErrors
fn deserialize<__D>(
__deserializer: __D,
) -> Result<IStablecoinDEXErrors, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<IStablecoinDEXErrors, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
impl Eq for IStablecoinDEXErrors
impl PartialEq for IStablecoinDEXErrors
impl PartialEq for IStablecoinDEXErrors
fn eq(&self, other: &IStablecoinDEXErrors) -> bool
fn eq(&self, other: &IStablecoinDEXErrors) -> bool
self and other values to be equal, and is used by ==.impl Serialize for IStablecoinDEXErrors
impl Serialize for IStablecoinDEXErrors
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
impl SolInterface for IStablecoinDEXErrors
impl SolInterface for IStablecoinDEXErrors
const MIN_DATA_LENGTH: usize = 0usize
const MIN_DATA_LENGTH: usize = 0usize
fn valid_selector(selector: [u8; 4]) -> bool
fn valid_selector(selector: [u8; 4]) -> bool
true if the given selector is known to this type.fn abi_decode_raw(
selector: [u8; 4],
data: &[u8],
) -> Result<IStablecoinDEXErrors, Error>
fn abi_decode_raw( selector: [u8; 4], data: &[u8], ) -> Result<IStablecoinDEXErrors, Error>
self.fn abi_decode_raw_validate(
selector: [u8; 4],
data: &[u8],
) -> Result<IStablecoinDEXErrors, Error>
fn abi_decode_raw_validate( selector: [u8; 4], data: &[u8], ) -> Result<IStablecoinDEXErrors, Error>
self, with validation. Read morefn abi_encoded_size(&self) -> usize
fn abi_encoded_size(&self) -> usize
fn abi_encode_raw(&self, out: &mut Vec<u8>)
fn abi_encode_raw(&self, out: &mut Vec<u8>)
self into the given buffer, without any selectors.fn type_check(selector: [u8; 4]) -> Result<(), Error>
fn type_check(selector: [u8; 4]) -> Result<(), Error>
fn abi_encode(&self) -> Vec<u8> ⓘ
fn abi_encode(&self) -> Vec<u8> ⓘ
self into the given buffer.fn abi_decode(data: &[u8]) -> Result<Self, Error>
fn abi_decode(data: &[u8]) -> Result<Self, Error>
self.fn abi_decode_validate(data: &[u8]) -> Result<Self, Error>
fn abi_decode_validate(data: &[u8]) -> Result<Self, Error>
self, with validation. Read moreimpl StructuralPartialEq for IStablecoinDEXErrors
impl TryFrom<TempoPrecompileError> for IStablecoinDEXErrors
impl TryFrom<TempoPrecompileError> for IStablecoinDEXErrors