Enum IStablecoinDEXEvents
pub enum IStablecoinDEXEvents {
PairCreated(PairCreated),
OrderPlaced(OrderPlaced),
OrderFilled(OrderFilled),
OrderFlipped(OrderFlipped),
FlipFailed(FlipFailed),
OrderCancelled(OrderCancelled),
}Expand description
Container for all the IStablecoinDEX events.
Variants
PairCreated(PairCreated)
OrderPlaced(OrderPlaced)
OrderFilled(OrderFilled)
OrderFlipped(OrderFlipped)
FlipFailed(FlipFailed)
OrderCancelled(OrderCancelled)
Implementations
impl IStablecoinDEXEvents
impl IStablecoinDEXEvents
pub const SELECTORS: &'static [[u8; 32]]
pub const SELECTORS: &'static [[u8; 32]]
All the selectors of this enum.
Note that the selectors might not be in the same order as the variants. No guarantees are made about the order of the selectors.
Prefer using SolInterface methods instead.
pub const VARIANT_NAMES: &'static [&'static str]
pub const VARIANT_NAMES: &'static [&'static str]
The names of the variants in the same order as SELECTORS.
pub const SIGNATURES: &'static [&'static str]
pub const SIGNATURES: &'static [&'static str]
The signatures in the same order as SELECTORS.
pub fn signature_by_selector(selector: [u8; 32]) -> Option<&'static str>
pub fn signature_by_selector(selector: [u8; 32]) -> Option<&'static str>
Returns the signature for the given selector, if known.
pub fn name_by_selector(selector: [u8; 32]) -> Option<&'static str>
pub fn name_by_selector(selector: [u8; 32]) -> Option<&'static str>
Returns the enum variant name for the given selector, if known.
impl IStablecoinDEXEvents
impl IStablecoinDEXEvents
pub fn pair_created(
key: FixedBytes<32>,
base: Address,
quote: Address,
) -> IStablecoinDEXEvents
pub fn pair_created( key: FixedBytes<32>, base: Address, quote: Address, ) -> IStablecoinDEXEvents
Creates a PairCreated event.
event PairCreated(bytes32,address,address)pub fn order_placed(
order_id: u128,
maker: Address,
token: Address,
amount: u128,
is_bid: bool,
tick: i16,
is_flip_order: bool,
flip_tick: i16,
) -> IStablecoinDEXEvents
pub fn order_placed( order_id: u128, maker: Address, token: Address, amount: u128, is_bid: bool, tick: i16, is_flip_order: bool, flip_tick: i16, ) -> IStablecoinDEXEvents
Creates a OrderPlaced event.
event OrderPlaced(uint128,address,address,uint128,bool,int16,bool,int16)pub fn order_filled(
order_id: u128,
maker: Address,
taker: Address,
amount_filled: u128,
partial_fill: bool,
) -> IStablecoinDEXEvents
pub fn order_filled( order_id: u128, maker: Address, taker: Address, amount_filled: u128, partial_fill: bool, ) -> IStablecoinDEXEvents
Creates a OrderFilled event.
event OrderFilled(uint128,address,address,uint128,bool)pub fn order_flipped(
order_id: u128,
maker: Address,
token: Address,
amount: u128,
is_bid: bool,
tick: i16,
flip_tick: i16,
) -> IStablecoinDEXEvents
pub fn order_flipped( order_id: u128, maker: Address, token: Address, amount: u128, is_bid: bool, tick: i16, flip_tick: i16, ) -> IStablecoinDEXEvents
Creates a OrderFlipped event.
event OrderFlipped(uint128,address,address,uint128,bool,int16,int16)pub fn flip_failed(
order_id: u128,
maker: Address,
reason: FixedBytes<4>,
) -> IStablecoinDEXEvents
pub fn flip_failed( order_id: u128, maker: Address, reason: FixedBytes<4>, ) -> IStablecoinDEXEvents
Creates a FlipFailed event.
event FlipFailed(uint128,address,bytes4)pub fn order_cancelled(order_id: u128) -> IStablecoinDEXEvents
pub fn order_cancelled(order_id: u128) -> IStablecoinDEXEvents
Creates a OrderCancelled event.
event OrderCancelled(uint128)Trait Implementations
impl Clone for IStablecoinDEXEvents
impl Clone for IStablecoinDEXEvents
fn clone(&self) -> IStablecoinDEXEvents
fn clone(&self) -> IStablecoinDEXEvents
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreimpl Debug for IStablecoinDEXEvents
impl Debug for IStablecoinDEXEvents
impl<'de> Deserialize<'de> for IStablecoinDEXEvents
impl<'de> Deserialize<'de> for IStablecoinDEXEvents
fn deserialize<__D>(
__deserializer: __D,
) -> Result<IStablecoinDEXEvents, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<IStablecoinDEXEvents, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
impl Eq for IStablecoinDEXEvents
impl IntoLogData for IStablecoinDEXEvents
impl IntoLogData for IStablecoinDEXEvents
fn to_log_data(&self) -> LogData
fn to_log_data(&self) -> LogData
LogData] object.fn into_log_data(self) -> LogData
fn into_log_data(self) -> LogData
LogData] object.impl PartialEq for IStablecoinDEXEvents
impl PartialEq for IStablecoinDEXEvents
fn eq(&self, other: &IStablecoinDEXEvents) -> bool
fn eq(&self, other: &IStablecoinDEXEvents) -> bool
self and other values to be equal, and is used by ==.impl Serialize for IStablecoinDEXEvents
impl Serialize for IStablecoinDEXEvents
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
impl SolEventInterface for IStablecoinDEXEvents
impl SolEventInterface for IStablecoinDEXEvents
fn decode_raw_log(
topics: &[FixedBytes<32>],
data: &[u8],
) -> Result<IStablecoinDEXEvents, Error>
fn decode_raw_log( topics: &[FixedBytes<32>], data: &[u8], ) -> Result<IStablecoinDEXEvents, Error>
fn decode_log(log: &Log) -> Result<Log<Self>, Error>
fn decode_log(log: &Log) -> Result<Log<Self>, Error>
impl StructuralPartialEq for IStablecoinDEXEvents